pub struct FloatExporter { /* private fields */ }Expand description
FloatExport is used by a Hier instance to make summations of multiple RunningFloat instances.
Implementations
Sourceimpl FloatExporter
FloatExporter creates a sum of RunningFloat instances.
impl FloatExporter
FloatExporter creates a sum of RunningFloat instances.
Sourcepub fn new() -> FloatExporter
pub fn new() -> FloatExporter
Creates a new FloatExporter instance.
Sourcepub fn push(&mut self, addend: Export)
pub fn push(&mut self, addend: Export)
Pushes a Rustics instance onto the list of instances to be summed.
Sourcepub fn make_member(
&mut self,
name: &str,
print_opts: &PrintOption,
) -> RunningFloat
pub fn make_member( &mut self, name: &str, print_opts: &PrintOption, ) -> RunningFloat
Makes a Rustics instance based on the given exports.
pub fn count(&self) -> usize